local _, DruidBuffs = ...

----------------------------------------------------------------------------------------------------
-- The text's frame
----------------------------------------------------------------------------------------------------
local textFrame = CreateFrame("frame", "DruidBuffsTextFrame", UIParent)
textFrame:SetSize(250, 30)
textFrame:SetPoint("TOP")
textFrame:SetFrameStrata("BACKGROUND")

-- the text
local buffText = textFrame:CreateFontString(nil, "OVERLAY", "GameFontNormalLarge")
buffText:SetPoint("CENTER")
DruidBuffs.buffText = buffText

-- load the previously saved position
function textFrame:RestorePosition()
	textFrame:ClearAllPoints()
	textFrame:SetPoint(
		DruidBuffsSave.textPosition.anchor1, UIParent, DruidBuffsSave.textPosition.anchor2,
		DruidBuffsSave.textPosition.offsetX, DruidBuffsSave.textPosition.offsetY)
end

-- save the current position
function textFrame:SavePosition()
	local _
	DruidBuffsSave.textPosition.anchor1, _, DruidBuffsSave.textPosition.anchor2,
		DruidBuffsSave.textPosition.offsetX, DruidBuffsSave.textPosition.offsetY = self:GetPoint(1)
end

-- load the text with saved settings
function DruidBuffs:LoadBuffText()
	self:UpdateTextSize()
	self:UpdateTextColor()
	if DruidBuffsSave.textPosition == nil then
		DruidBuffsSave.textPosition = {}
		textFrame:SavePosition()
	else
		textFrame:RestorePosition()
	end
end

function DruidBuffs:UpdateTextSize()
	buffText:SetFont("Fonts/FRIZQT__.TTF", DruidBuffsSave.textSize, "OUTLINE")
end

function DruidBuffs:UpdateTextColor()
	buffText:RestoreColor()
end

-- set it to be movable when holding shift
textFrame:SetMovable(true)
textFrame:EnableMouse(true)
textFrame:RegisterForDrag("LeftButton")
textFrame:SetScript("OnDragStart", function(self)
	if IsShiftKeyDown() then
		self:StartMoving()
	end
end)
textFrame:SetScript("OnDragStop", textFrame.StopMovingOrSizing)
textFrame:SetScript("OnMouseDown", function(self, button)
	if button == "LeftButton" and IsShiftKeyDown() and not self.isMoving then
		self:StartMoving()
		self.isMoving = true
	end
end)
textFrame:SetScript("OnMouseUp", function(self, button)
	if button == "LeftButton" and self.isMoving then
		self:StopMovingOrSizing()
		self.isMoving = false
		self:SavePosition()
	end
end)
textFrame:SetScript("OnHide", function(self)
	if self.isMoving then
		self:StopMovingOrSizing()
		self.isMoving = false
		self:SavePosition()
	end
end)

--------------------------------------------------
-- color picker for the text color
--------------------------------------------------
function buffText:RestoreColor()
	local tc = DruidBuffsSave.textColor
	buffText:SetTextColor(tc[1], tc[2], tc[3], 1)
	DruidBuffs.exampleText:SetTextColor(tc[1], tc[2], tc[3], 1)
end

-- called when the color changes or the picker is canceled
function buffText.ColorPickerCallback(restore)
	local tc = DruidBuffsSave.textColor
	if restore then
		tc[1], tc[2], tc[3] = unpack(restore)
	else
		tc[1], tc[2], tc[3] = ColorPickerFrame:GetColorRGB()
	end
	buffText:RestoreColor()
end

-- open and show the color picker
function DruidBuffs:ShowColorPicker()
	local tc = DruidBuffsSave.textColor
	ColorPickerFrame:SetColorRGB(tc[1], tc[2], tc[3])
	ColorPickerFrame.hasOpacity, ColorPickerFrame.opacity = nil, nil
	ColorPickerFrame.previousValues = {tc[1], tc[2], tc[3]}
	ColorPickerFrame.func, ColorPickerFrame.opacityFunc, ColorPickerFrame.cancelFunc =
		buffText.ColorPickerCallback, buffText.ColorPickerCallback, buffText.ColorPickerCallback
	ColorPickerFrame:Hide() -- if already opened, need to reopen to update color
	ColorPickerFrame:Show()
end
