local _, DruidBuffs = ...

----------------------------------------------------------------------------------------------------
-- Key binding buttons to toggle using Thorns
----------------------------------------------------------------------------------------------------
local buttonToggleThornsOnTarget = CreateFrame("Button", "DruidBuffsToggleThornsOnTarget", nil, "SecureActionButtonTemplate")
buttonToggleThornsOnTarget:SetAttribute("type", "macro")
buttonToggleThornsOnTarget:SetAttribute("macrotext", "/druidbuffs togglethorns target")

local buttonToggleThornsOnSelf = CreateFrame("Button", "DruidBuffsToggleThornsOnSelf", nil, "SecureActionButtonTemplate")
buttonToggleThornsOnSelf:SetAttribute("type", "macro")
buttonToggleThornsOnSelf:SetAttribute("macrotext", "/druidbuffs togglethorns player")

function DruidBuffs:ToggleThorns(unit)
	local name

	if not UnitExists(unit) then
		DEFAULT_CHAT_FRAME:AddMessage("You aren't targeting anyone.", 1, 0, 0)
		return
	end
	if not UnitIsFriend("player", unit) then
		DEFAULT_CHAT_FRAME:AddMessage(UnitName(unit) .. " isn't a friendly player or pet!", 1, 0, 0)
		return
	end

	if UnitIsPlayer(unit) then
		name = UnitName(unit)
	-- for pets, go through group to find owner - could change to reading tooltip to allow non-group pets but that seems mostly useless
	elseif UnitIsOtherPlayersPet(unit) then
		name = DruidBuffs:ConvertPetToUnit(unit)
		if not name then
			DEFAULT_CHAT_FRAME:AddMessage(UnitName(unit) .. " doesn't seem to be a group member's pet.", 1, 0, 0)
			return
		end
	else
		DEFAULT_CHAT_FRAME:AddMessage(UnitName(unit) .. " isn't a player's pet!", 1, 0, 0)
		return
	end

	if DruidBuffsSave.thornsList[name] then
		DruidBuffsSave.thornsList[name] = nil
		DEFAULT_CHAT_FRAME:AddMessage(name .. " will no longer be given Thorns.")
	else
		DruidBuffsSave.thornsList[name] = true
		DEFAULT_CHAT_FRAME:AddMessage(name .. " will be given Thorns.")
	end
	DruidBuffs:SetNextBuff()
end

----------------------------------------------------------------------------------------------------
-- /druidbuffs command
----------------------------------------------------------------------------------------------------
_G.SLASH_DRUIDBUFFS1 = "/druidbuffs"
function SlashCmdList.DRUIDBUFFS(input)
	local command, value = input:match("^%s*(%S+)%s*(%S*)")
	command = command and command:lower()
	value = value and value:lower()

	if command == "togglethorns" then
		DruidBuffs:ToggleThorns(value)
		return
	end

	local location = DruidBuffs:GetLocation()
	local locationSettings = DruidBuffsSave[location]
	local locationPanel = DruidBuffs["settingsPanel" .. location]

	if not input or input == "" then
		InterfaceOptionsFrame_Show()
		InterfaceOptionsFrame_OpenToCategory(locationPanel)
		return
	end

	if command == "mark" then
		if value == "on" then
			locationSettings.checkMark = true
		elseif value == "off" then
			locationSettings.checkMark = false
		else
			DEFAULT_CHAT_FRAME:AddMessage('Usage: /druidbuffs mark <"on"|"off">')
		end
		DEFAULT_CHAT_FRAME:AddMessage("Checking for MotW is " .. (locationSettings.checkMark and "ON" or "OFF") .. " here.")
		locationPanel:UpdateSettingDisplay()
		DruidBuffs:SetNextBuff()
		return
	end

	if command == "thorns" then
		if value == "on" then
			locationSettings.checkThorns = true
		elseif value == "off" then
			locationSettings.checkThorns = false
		else
			DEFAULT_CHAT_FRAME:AddMessage('Usage: /druidbuffs thorns <"on"|"off">')
		end
		DEFAULT_CHAT_FRAME:AddMessage("Checking for Thorns is " .. (locationSettings.checkThorns and "ON" or "OFF") .. " here.")
		locationPanel:UpdateSettingDisplay()
		DruidBuffs:SetNextBuff()
		return
	end

	if command == "gift" then
		if value == "on" then
			locationSettings.useGift = true
		elseif value == "off" then
			locationSettings.useGift = false
		else
			DEFAULT_CHAT_FRAME:AddMessage('Usage: /druidbuffs gift <"on"|"off">')
		end
		DEFAULT_CHAT_FRAME:AddMessage("Using Gift of the Wild is " .. (locationSettings.useGift and "ON" or "OFF") .. " here.")
		locationPanel:UpdateSettingDisplay()
		DruidBuffs:SetNextBuff()
		return
	end

	if command == "show" or command == "showtext" then
		if value == "on" then
			locationSettings.showText = true
		elseif value == "off" then
			locationSettings.showText = false
		else
			DEFAULT_CHAT_FRAME:AddMessage('Usage: /druidbuffs showtext <"on"|"off">')
		end
		DEFAULT_CHAT_FRAME:AddMessage("Showing the buff text is " .. (locationSettings.showText and "ON" or "OFF") .. " here.")
		locationPanel:UpdateSettingDisplay()
		DruidBuffs:SetNextBuff()
		return
	end

	DEFAULT_CHAT_FRAME:AddMessage("Druid Buffs commands:", 1, 1, 0)
	DEFAULT_CHAT_FRAME:AddMessage("/druidbuffs (open settings window)")
	DEFAULT_CHAT_FRAME:AddMessage('/druidbuffs mark <"on"|"off">')
	DEFAULT_CHAT_FRAME:AddMessage('/druidbuffs thorns <"on"|"off">')
	DEFAULT_CHAT_FRAME:AddMessage('/druidbuffs gift <"on"|"off">')
	DEFAULT_CHAT_FRAME:AddMessage('/druidbuffs showtext <"on"|"off">')
end
